import os
import sys

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)

from datetime import datetime
import pandas as pd
from loguru import logger

import mns_common.component.common_service_fun_api as common_service_fun_api
import mns_common.component.concept.ths_concept_common_service_api as ths_concept_common_service_api
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.api.kpl.symbol.kpl_real_time_quotes_api as kpl_real_time_quotes_api
import mns_common.utils.data_frame_util as data_frame_util
import mns_common.component.k_line.common.k_line_common_service_api as k_line_common_service_api
import mns_common.constant.db_name_constant as db_name_constant
from mns_scheduler.company_info.common.company_common_query_service import get_company_info
import mns_scheduler.company_info.sync.company_info_set_service as company_info_set_service
import mns_scheduler.company_info.constant.company_constant_data as company_constant_data

mongodb_util = MongodbUtil('27017')
# 分页大小
MAX_PAGE_NUMBER = 500
import threading

# 定义一个全局锁，用于保护 result 变量的访问
result_lock = threading.Lock()
# 初始化 result 变量为一个空的 Pandas DataFrame
result = []


# 同步公司基本信息

def sync_company_base_info(symbol_list):
    global result
    result = []

    east_money_stock_info = get_company_info()

    east_money_stock_info = common_service_fun_api.total_mv_classification(east_money_stock_info)
    east_money_stock_info = common_service_fun_api.classify_symbol(east_money_stock_info)
    # 将日期数值转换为日期时间格式
    east_money_stock_info['list_date_01'] = pd.to_datetime(east_money_stock_info['list_date'], format='%Y%m%d')
    # 开盘啦实时数据
    kpl_real_time_quotes = kpl_real_time_quotes_api.get_kpl_real_time_quotes()
    if len(symbol_list) > 0:
        east_money_stock_info = east_money_stock_info.loc[east_money_stock_info['symbol'].isin(symbol_list)]
    count = east_money_stock_info.shape[0]
    page_number = round(count / MAX_PAGE_NUMBER, 0) + 1
    page_number = int(page_number)
    threads = []
    # 创建多个线程来获取数据
    for page in range(page_number):  # 0到100页
        end_count = (page + 1) * MAX_PAGE_NUMBER
        begin_count = page * MAX_PAGE_NUMBER
        page_df = east_money_stock_info.iloc[begin_count:end_count]
        thread = threading.Thread(target=single_thread_sync_company_info,
                                  args=(page_df, kpl_real_time_quotes))
        threads.append(thread)
        thread.start()

    # 等待所有线程完成
    for thread in threads:
        thread.join()

    fail_df = east_money_stock_info.loc[east_money_stock_info['symbol'].isin(result)]
    single_thread_sync_company_info(fail_df, kpl_real_time_quotes)


def single_thread_sync_company_info(east_money_stock_info,
                                    kpl_real_time_quotes):
    global result
    fail_list = []
    for company_one in east_money_stock_info.itertuples():
        try:

            company_one_df = east_money_stock_info.loc[east_money_stock_info['symbol'] == company_one.symbol]

            company_one_df = company_one_df.rename(columns={
                "industry": "em_industry",
                "concept": "em_concept"
            })
            now_date = datetime.now()
            str_day = now_date.strftime('%Y-%m-%d')
            str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')

            # 计算日期差值 距离现在上市时间
            company_one_df['diff_days'] = (now_date - company_one.list_date_01).days
            company_one_df = company_one_df[[
                'symbol',
                'name',
                'em_industry',
                'em_concept',
                'hk_stock_code',
                'hk_stock_name',
                'amount',
                'now_price',
                'total_share',
                'flow_share',
                'total_mv',
                'flow_mv',
                'area',
                'list_date',
                'diff_days',
                'pe_ttm',
                'pb',
                'ROE',
                'flow_mv_sp',
                'total_mv_sp',
                'flow_mv_level',
                'classification',
            ]]

            company_one_df['sync_date'] = str_now_date

            # 行业信息
            company_industry_info_df = mongodb_util.find_query_data(db_name_constant.COMPANY_INDUSTRY_INFO,
                                                                    {"symbol": company_one.symbol})

            if data_frame_util.is_empty(company_industry_info_df):
                company_one_df['business_nature'] = '数据异常'
                company_one_df['holder_controller_name'] = '数据异常'
                company_one_df['holder_controller_rate'] = 0
                company_one_df['final_controller_name'] = '数据异常'
                company_one_df['final_controller_rate'] = 0
                company_one_df['actual_controller_name'] = '数据异常'
                company_one_df['actual_controller_rate'] = 0
                company_one_df['base_business'] = ''
                company_one_df['intro'] = ''
                company_one_df['address'] = ''
                company_one_df['market_id'] = ''
                company_one_df['main_business_list'] = [[] for _ in range(len(company_one_df))]
                company_one_df['most_profitable_business'] = ''
                company_one_df['most_profitable_business_rate'] = '0'
                company_one_df['most_profitable_business_profit'] = 0
                company_one_df['first_industry_code'] = '0'
                company_one_df['second_industry_code'] = '0'
                company_one_df['third_industry_code'] = '0'
                company_one_df['first_sw_industry'] = '数据异常'
                company_one_df['second_sw_industry'] = '数据异常'
                company_one_df['third_sw_industry'] = '数据异常'
                company_one_df['industry'] = '数据异常'
            else:

                del company_industry_info_df['_id']
                del company_industry_info_df['name']
                # 申万二级行业 作业行业
                company_industry_info_df['industry'] = company_industry_info_df['second_sw_industry']

                company_industry_info_df = company_industry_info_df.set_index(['symbol'], drop=True)
                company_one_df = company_one_df.set_index(['symbol'], drop=False)
                company_one_df = pd.merge(company_one_df, company_industry_info_df, how='outer',
                                          left_index=True, right_index=True)

            # 设置流通比例和外资持股
            company_one_df = company_info_set_service.set_calculate_circulation_ratio(company_one.symbol, str_day,
                                                                                      company_one_df)

            # 获取同花顺最新概念
            company_one_df = ths_concept_common_service_api.set_ths_concept(company_one.symbol, company_one_df)
            # 修改行业
            fix_symbol_industry_df = company_constant_data.get_fix_symbol_industry()
            if company_one.symbol in list(fix_symbol_industry_df['symbol']):
                # fix sw_industry
                company_one_df = company_constant_data.fix_symbol_industry(company_one_df,
                                                                           company_one.symbol)

            # 交易天数
            deal_days = k_line_common_service_api.get_deal_days(str_day, company_one.symbol)
            company_one_df['deal_days'] = deal_days

            # 设置财务年报信息
            company_one_df = company_info_set_service.set_recent_year_income(company_one.symbol, company_one_df)
            # 设置开盘信息
            company_one_df['kpl_plate_list_info'] = '-'
            company_one_df['kpl_plate_name'] = '-'
            company_one_df['kpl_most_relative_name'] = '-'
            company_one_df = company_info_set_service.set_kpl_plate_info(company_one_df, company_one,
                                                                         kpl_real_time_quotes)
            # 设置可转债 信息
            company_one_df['kzz_debt_list'] = [[] for _ in range(len(company_one_df))]
            company_one_df = company_info_set_service.set_kzz_debt(company_one_df, company_one.symbol)

            company_one_df['_id'] = company_one_df['symbol']

            company_one_df = company_constant_data.filed_sort(company_one_df)
            mongodb_util.save_mongo(company_one_df.copy(), db_name_constant.COMPANY_INFO_TEMP)
            logger.info("同步公司信息完成:{}", company_one.symbol + '-' + company_one.name)
        except BaseException as e:
            fail_list.append(company_one.symbol)
            logger.error("同步公司信息发生异常:{},{}", company_one.symbol, e)
    with result_lock:
        # 使用锁来保护 result 变量的访问，将每页的数据添加到结果中
        result = fail_list


if __name__ == '__main__':

    sync_company_base_info(['600030'])
    # sync_company_base_info([])



import sys
import os
import time

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.constant.db_name_constant as db_name_constant
import mns_common.utils.data_frame_util as data_frame_util
import mns_common.component.deal.deal_service_api as deal_service_api
from loguru import logger
from mns_common.utils.async_fun import async_fun
import mns_common.component.common_service_fun_api as common_service_fun_api
import mns_common.utils.date_handle_util as date_handle_util
import pandas as pd

mongodb_util = MongodbUtil('27017')
from datetime import datetime


def auto_da_ban_task():
    logger.info("打板任务启动")
    while True:
        try:
            now_date = datetime.now()
            now_str_day = now_date.strftime('%Y-%m-%d')
            if bool(1 - date_handle_util.is_trade_date(now_str_day)):
                logger.info("非交易日不执行:{}", now_str_day)
                break
            else:
                # 执行打板任务
                auto_da_ban()
        except BaseException as e:
            logger.error("自动打板定时任务异常:{}", e)


def auto_da_ban():
    now_date = datetime.now()
    now_str_day = now_date.strftime('%Y-%m-%d')
    over_night_da_ban_list = query_over_night_da_ban_list(now_str_day)
    if data_frame_util.is_empty(over_night_da_ban_list):
        return None
    for stock_one in over_night_da_ban_list.itertuples():
        try:
            symbol = stock_one.symbol
            buy_price = stock_one.zt_price
            buy_volume = stock_one.buy_volume
            xia_dan_to_qmt(symbol, buy_price, buy_volume, now_str_day)
        except BaseException as e:
            logger.error("隔夜委托出现异常:{},{}", symbol, e)


def xia_dan_to_qmt(symbol, buy_price, buy_volume, str_day):
    symbol_prefix = common_service_fun_api.add_after_prefix_one(symbol)

    deal_service_api.trade_buy(symbol_prefix, buy_price, buy_volume, 'qmt')

    # 异步更新信息
    handle_async_msg(str_day, symbol, symbol_prefix)


@async_fun
def handle_async_msg(str_day, symbol, symbol_prefix):
    order_list = deal_service_api.query_orders('qmt')
    order_list_df = pd.DataFrame(order_list)
    # order_status ==57 费单
    success_order_df = order_list_df.loc[
        (order_list_df['stock_code'] == symbol_prefix) & (order_list_df['order_status'] != 57)]
    # 多委托几个
    time.sleep(1)
    # 委托成功 更新状态
    if data_frame_util.is_not_empty(success_order_df):
        logger.info("隔夜委托成功:{}", symbol)
        query = {"str_day": str_day, "symbol": symbol}
        new_values = {"$set": {"valid": False}}
        mongodb_util.update_many(query, new_values, db_name_constant.OVER_NIGHT_DA_BAN)


def query_over_night_da_ban_list(str_day):
    query = {"str_day": str_day, "valid": True}
    return mongodb_util.find_query_data(db_name_constant.OVER_NIGHT_DA_BAN, query)


if __name__ == '__main__':
    while True:
        auto_da_ban()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
# 同步当天所有开盘数据
import mns_common.utils.date_handle_util as date_handle_util
from loguru import logger
from datetime import time
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.component.common_service_fun_api as common_service_fun_api
import mns_common.component.company.company_common_service_new_api as company_common_service_new_api
import mns_common.component.data.data_init_api as data_init_api
import mns_common.utils.db_util as db_util
import mns_common.utils.data_frame_util as data_frame_util
import mns_common.constant.db_name_constant as db_name_constant

mongodb_util = MongodbUtil('27017')


def sync_one_day_open_data(str_day):
    realtime_quotes_db_name = 'realtime_quotes_now_' + str_day

    number = db_util.get_realtime_quotes_now_min_number(str_day, None, None)

    query = {"number": number}
    db = db_util.get_db(str_day)
    realtime_quotes_now_list = db.find_query_data(realtime_quotes_db_name, query)

    realtime_quotes_now_one = realtime_quotes_now_list.iloc[0]
    str_now_date = realtime_quotes_now_one['_id']
    str_now_date = str_now_date[7:26]

    now_date = date_handle_util.str_to_date(str_now_date, "%Y-%m-%d %H:%M:%S")
    now_date_time = now_date.time()

    target_time_09_31 = time(9, 31)
    if now_date_time >= target_time_09_31:
        return

    realtime_quotes_now_list['str_day'] = str_day

    realtime_quotes_now_list = handle_init_real_time_quotes_data(
        realtime_quotes_now_list.copy(),
        str_now_date, number)

    mongodb_util.insert_mongo(realtime_quotes_now_list, 'realtime_quotes_now_open')

    logger.info("同步str_day:{}开盘数据", str_day)


def handle_init_real_time_quotes_data(real_time_quotes_now, str_now_date, number):
    #  fix industry
    real_time_quotes_now = company_common_service_new_api.amend_ths_industry(real_time_quotes_now.copy())
    #  exclude b symbol
    real_time_quotes_now = common_service_fun_api.exclude_b_symbol(real_time_quotes_now.copy())
    #  classification symbol
    real_time_quotes_now = common_service_fun_api.classify_symbol(real_time_quotes_now.copy())

    #  calculate parameter
    real_time_quotes_now = data_init_api.calculate_parameter_factor(real_time_quotes_now.copy())

    real_time_quotes_now = real_time_quotes_now.loc[real_time_quotes_now['amount'] != 0]
    real_time_quotes_now['str_now_date'] = str_now_date
    real_time_quotes_now['number'] = number
    return real_time_quotes_now


def choose_open_data_field(realtime_quotes_now_all_df, str_day):
    if data_frame_util.is_empty(realtime_quotes_now_all_df):
        logger.error("当天无开盘数据:{}", str_day)
        return None

    if 'up_speed_05' not in realtime_quotes_now_all_df.columns:
        realtime_quotes_now_all_df['up_speed_05'] = realtime_quotes_now_all_df['up_speed']

    if 'sell_1_num' not in realtime_quotes_now_all_df.columns:
        realtime_quotes_now_all_df['sell_1_num'] = 0

    if 'buy_1_num' not in realtime_quotes_now_all_df.columns:
        realtime_quotes_now_all_df['buy_1_num'] = 0

    if 'wei_bi' not in realtime_quotes_now_all_df.columns:
        realtime_quotes_now_all_df['wei_bi'] = 0

    if bool(1 - ("disk_diff_amount_exchange" in realtime_quotes_now_all_df.columns)) or bool(
            1 - ("disk_diff_amount" in realtime_quotes_now_all_df.columns)):
        try:
            if 'average_price' in realtime_quotes_now_all_df.columns:
                # 外盘与内盘的金额差额 100 为1手
                realtime_quotes_now_all_df['disk_diff_amount'] = round(
                    (realtime_quotes_now_all_df['outer_disk'] - realtime_quotes_now_all_df['inner_disk']) *
                    realtime_quotes_now_all_df[
                        "average_price"] * 100,
                    2)
            else:
                # 外盘与内盘的金额差额
                realtime_quotes_now_all_df['disk_diff_amount'] = round(
                    (realtime_quotes_now_all_df['outer_disk'] - realtime_quotes_now_all_df['inner_disk']) *
                    realtime_quotes_now_all_df[
                        "now_price"] * 100,
                    2)
        except BaseException as e:
            realtime_quotes_now_all_df['disk_diff_amount'] = 0
            logger.error("出现异常:{}", e)
        realtime_quotes_now_all_df.loc[:, 'reference_main_inflow'] = round(
            (realtime_quotes_now_all_df['flow_mv'] * (1 / 1000)), 2)

        realtime_quotes_now_all_df['disk_diff_amount_exchange'] = round(
            (realtime_quotes_now_all_df['disk_diff_amount'] / realtime_quotes_now_all_df['flow_mv']) * 1000, 2)

    if 'real_disk_diff_amount_exchange' not in realtime_quotes_now_all_df.columns:
        realtime_quotes_now_all_df['real_disk_diff_amount_exchange'] = realtime_quotes_now_all_df[
            'disk_diff_amount_exchange']

    if 'sum_main_inflow_disk' not in realtime_quotes_now_all_df.columns:
        realtime_quotes_now_all_df['sum_main_inflow_disk'] = realtime_quotes_now_all_df[
            'disk_diff_amount_exchange']

    realtime_quotes_now_all_df = realtime_quotes_now_all_df[[
        "_id",
        "symbol",
        "chg",
        "quantity_ratio",
        "disk_ratio",
        "exchange",
        "amount",

        "real_disk_diff_amount_exchange",
        "disk_diff_amount_exchange",
        'disk_diff_amount',
        'sum_main_inflow_disk',
        'today_main_net_inflow',

        'large_order_net_inflow',
        'super_large_order_net_inflow',
        "now_price",
        "high",
        "low",
        "open",
        "yesterday_price",
        "volume",
        "total_mv",
        "flow_mv",
        "wei_bi",
        "buy_1_num",
        "outer_disk",
        "inner_disk",
        "average_price",
        "str_now_date",
        'up_speed',
        'up_speed_05',
        'sell_1_num',
        "number",
        'today_main_net_inflow_ratio',
        'super_large_order_net_inflow_ratio'
    ]]

    return realtime_quotes_now_all_df


def get_realtime_quotes_now_call_auction_max_number(str_day, field, symbol):
    if field is None:
        field = 'number'
    if symbol is None:
        symbol = '000001'
    realtime_quotes_db_name = 'realtime_quotes_now_' + str_day

    min_str_now_date = str_day + " 09:25:30"
    max_str_now_date = str_day + " 09:30:00"
    query = {'symbol': symbol,
             '$and': [{"str_now_date": {"$gte": min_str_now_date}},
                      {"str_now_date": {"$lt": max_str_now_date}}]}
    df = mongodb_util.descend_query(query, realtime_quotes_db_name, field, 1)
    if df is None or df.shape[0] == 0:
        logger.error("没有开盘数据:{}", str_day)
        return 0
    else:
        return list(df[field])[0]


def create_index(db_name):
    mongodb_util.create_index(db_name, [("str_day", 1)])


def sync_call_auction_data(str_day):
    realtime_quotes_db_name = 'realtime_quotes_now_' + str_day
    number = get_realtime_quotes_now_call_auction_max_number(str_day, None, None)

    query = {"number": number}
    realtime_quotes_now_list = mongodb_util.find_query_data(realtime_quotes_db_name, query)

    if data_frame_util.is_empty(realtime_quotes_now_list):
        logger.error("没有开盘数据:{}", str_day)
    else:
        realtime_quotes_now_list = choose_open_data_field(
            realtime_quotes_now_list.copy(), str_day)
        realtime_quotes_now_list['str_day'] = str_day
        now_year = str_day[0:4]
        db_name = db_name_constant.CALL_AUCTION_OPEN_DATA + '_' + now_year
        # 创建索引
        create_index(db_name)
        mongodb_util.save_mongo(realtime_quotes_now_list, db_name)
        logger.info("同步开盘数据:{}", str_day)


if __name__ == '__main__':
    sync_call_auction_data('2026-03-09')



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.component.deal.deal_service_api as deal_service_api
import pandas as pd
import mns_common.utils.data_frame_util as data_frame_util
import mns_common.constant.db_name_constant as db_name_constant
from datetime import datetime
from mns_common.component.deal.terminal_enum import TerminalEnum
from mns_common.db.MongodbUtil import MongodbUtil

mongodb_util = MongodbUtil('27017')


# 同步持仓
def sync_position_ths():
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    query_exist = {'str_day': str_day}
    if mongodb_util.exist_data_query(db_name_constant.POSITION_STOCK, query_exist):
        return None
    position_list = deal_service_api.get_position('easy_trader')
    position_df = pd.DataFrame(position_list)
    position_df = position_df.rename(columns={"明细": "detail",
                                              "序号": "index",
                                              "证券代码": "symbol",
                                              "证券名称": "name",
                                              "持仓数量": "open_position",
                                              "可用数量": "available_position",
                                              "冻结数量": "frozen_position",
                                              "参考成本价": "cost_price",
                                              "当前价": "now_price",
                                              "浮动盈亏": "floating_profit_loss",
                                              "盈亏比例(%)": "profit_loss_percent",
                                              "最新市值": "flow_mv",
                                              "当日盈亏": "today_profit_loss",
                                              "当日盈亏比(%)": "today_profit_loss_percent",
                                              "仓位占比(%)": "position_ratio",
                                              "持股天数": "holding_days",
                                              "当日买入": "day_buy",
                                              "当日卖出": "day_sell",
                                              "交易市场": "market"
                                              })
    if data_frame_util.is_not_empty(position_df):
        position_df["_id"] = position_df['symbol'] + '-' + str_day
        position_df["str_day"] = str_day
        position_df["valid"] = True
        mongodb_util.save_mongo(position_df, db_name_constant.POSITION_STOCK)


def sync_position_qmt():
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    query_exist = {'str_day': str_day}
    # if mongodb_util.exist_data_query(db_name_constant.POSITION_STOCK, query_exist):
    #     return None
    position_list = deal_service_api.get_position(TerminalEnum.QMT.terminal_code)
    if len(position_list) == 0:
        return None
    position_df = pd.DataFrame(position_list)
    position_df = position_df.rename(columns={
        "stock_code": "symbol",
        "avg_price": "cost_price",
        "profit_loss": "floating_profit_loss",
        "market_value": "flow_mv",
        "can_use_volume": "available_position",
        "frozen_volume": "frozen_position",
    })

    position_df['cost_price'] = round(position_df['cost_price'], 2)
    position_df['open_price'] = round(position_df['open_price'], 2)

    position_df['open_position'] = position_df['available_position'] + position_df['frozen_position'] + position_df[
        'on_road_volume']

    position_df['symbol'] = position_df['symbol'].str.slice(0, 6)

    position_df["_id"] = position_df['symbol'] + '-' + str_day
    position_df["str_day"] = str_day
    position_df["valid"] = True
    mongodb_util.save_mongo(position_df, db_name_constant.POSITION_STOCK)


if __name__ == '__main__':
    sync_position_qmt()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
from datetime import datetime
import mns_common.component.tfp.stock_tfp_api as stock_tfp_api
import mns_common.constant.db_name_constant as db_name_constant
import mns_common.utils.data_frame_util as data_frame_util
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.component.common_service_fun_api as common_service_fun_api

mongodb_util = MongodbUtil('27017')


def sync_stock_tfp(str_day):
    if str_day is None:
        now_date = datetime.now()
        last_year = now_date.year - 1
        init_str_day = str(last_year) + '-01' + '-01'
        stock_tfp_df = stock_tfp_api.get_stock_tfp_by_day(init_str_day)
        str_day = now_date.strftime('%Y-%m-%d')
        stock_tfp_df = handle_tfp_data(stock_tfp_df.copy(), str_day, 1)
    else:
        stock_tfp_df = stock_tfp_api.get_stock_tfp_by_day(str_day)
        stock_tfp_df = handle_tfp_data(stock_tfp_df.copy(), str_day, 2)

    return stock_tfp_df


def handle_tfp_data(stock_tfp_df, str_day, time_classify):
    if data_frame_util.is_not_empty(stock_tfp_df):
        stock_tfp_df['sus_begin_time'] = stock_tfp_df['sus_begin_time'].fillna('无')
        stock_tfp_df['sus_end_time'] = stock_tfp_df['sus_end_time'].fillna('无')
        stock_tfp_df['resume_time'] = stock_tfp_df['resume_time'].fillna('无')
        stock_tfp_df['_id'] = stock_tfp_df['symbol'] + "_" + str_day
        # 排除name列中值包含'B'的行
        stock_tfp_df = stock_tfp_df[~stock_tfp_df['name'].str.contains('B', na=False)]

        stock_tfp_df['sus_begin_time'] = stock_tfp_df['sus_begin_time'].astype(str)
        stock_tfp_df['sus_end_time'] = stock_tfp_df['sus_end_time'].astype(str)
        stock_tfp_df['resume_time'] = stock_tfp_df['resume_time'].astype(str)
        stock_tfp_df['sus_begin_date'] = stock_tfp_df['sus_begin_date'].astype(str)
        stock_tfp_df = common_service_fun_api.exclude_st_symbol(stock_tfp_df)
        # 根据条件设置新列'type'的值

        # 初始化类型值
        stock_tfp_df['type'] = '0'
        stock_tfp_df.loc[stock_tfp_df['sus_reason'] == '盘中停牌', 'type'] = '0'
        stock_tfp_df.loc[stock_tfp_df['sus_reason'] == '停牌一天', 'type'] = '1'
        stock_tfp_df.loc[stock_tfp_df['sus_reason'] == '连续停牌', 'type'] = '2'
        stock_tfp_df.loc[stock_tfp_df['sus_reason'] == '刊登重要公告', 'type'] = '3'
        stock_tfp_df.loc[stock_tfp_df['sus_reason'] == '拟筹划重大资产重组', 'type'] = '4'
        stock_tfp_df.loc[stock_tfp_df['sus_reason'] == '交易异常波动', 'type'] = '5'
        stock_tfp_df['valid'] = True
        stock_tfp_df['str_day'] = str_day
        stock_tfp_df.loc[stock_tfp_df['type'] == '2', 'valid'] = False
        stock_tfp_df.loc[stock_tfp_df['type'] == '1', 'valid'] = False

        if time_classify == 1:
            stock_tfp_df = stock_tfp_df.loc[(stock_tfp_df['sus_begin_time'] >= str_day)
                                            | (stock_tfp_df['sus_end_time'] >= str_day)
                                            | (stock_tfp_df['resume_time'] >= str_day)
                                            | (stock_tfp_df['sus_begin_date'] >= str_day)]

            stock_tfp_df = stock_tfp_df.loc[stock_tfp_df['sus_period'] != '盘中停牌']
        # 停复牌
        stock_tfp_df = stock_tfp_df.fillna(0)
        mongodb_util.save_mongo(stock_tfp_df, db_name_constant.STOCK_TFP_INFO)
        return stock_tfp_df


if __name__ == '__main__':
    df = sync_stock_tfp(None)
    print(df)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.constant.db_name_constant as db_name_constant
from datetime import datetime
import mns_common.utils.data_frame_util as data_frame_util
import mns_common.api.em.gd.east_stock_gd_free_top_10_by_period_api as east_stock_gd_free_top_10_by_period_api
import mns_common.api.em.gd.east_stock_gd_top_10_by_period_api as east_stock_gd_top_10_by_period_api
import mns_common.utils.common_util as common_util
from loguru import logger

mongodb_util = MongodbUtil('27017')


# 同步十大流通股东
def sync_top_ten_free_gd_task(period, is_new):
    big_df = east_stock_gd_free_top_10_by_period_api.stock_gdfx_free_holding_analyse_em(period, is_new)
    now_date = datetime.now()
    sync_time = now_date.strftime('%Y-%m-%d %H:%M:%S')
    create_day = now_date.strftime('%Y-%m-%d')
    big_df['create_day'] = create_day
    big_df['sync_time'] = sync_time
    big_df['update_time'] = sync_time
    big_df['_id'] = big_df['symbol'] + '_' + big_df['period'] + '_' + big_df['shares_number_str']
    query_exist = {'period': period}
    stock_gdfx_top_10_new_df_exist = mongodb_util.find_query_data(db_name_constant.STOCK_GDFX_FREE_TOP_10_NEW,
                                                                  query_exist)
    if data_frame_util.is_not_empty(stock_gdfx_top_10_new_df_exist):
        symbol_mapping_create_day = dict(
            zip(stock_gdfx_top_10_new_df_exist['symbol'], stock_gdfx_top_10_new_df_exist['create_day']))

        symbol_mapping_sync_time = dict(
            zip(stock_gdfx_top_10_new_df_exist['symbol'], stock_gdfx_top_10_new_df_exist['sync_time']))

        big_df['create_day'] = big_df['symbol'].map(
            symbol_mapping_create_day).fillna(create_day)
        big_df['sync_time'] = big_df['symbol'].map(
            symbol_mapping_sync_time).fillna(create_day)

    mongodb_util.save_mongo(big_df, db_name_constant.STOCK_GDFX_FREE_TOP_10_NEW)


# 同步十大股东
def sync_top_ten_gd_task(period, is_new):
    big_df = east_stock_gd_top_10_by_period_api.stock_gdfx_holding_analyse_em(period, is_new)
    now_date = datetime.now()
    sync_time = now_date.strftime('%Y-%m-%d %H:%M:%S')
    create_day = now_date.strftime('%Y-%m-%d')
    big_df['create_day'] = create_day
    big_df['sync_time'] = sync_time
    big_df['update_time'] = sync_time
    big_df['_id'] = big_df['symbol'] + '_' + big_df['period'] + '_' + big_df['shares_number_str']
    query_exist = {'period': period}
    stock_gdfx_top_10_new_df_exist = mongodb_util.find_query_data(db_name_constant.STOCK_GDFX_TOP_10_NEW,
                                                                  query_exist)
    if data_frame_util.is_not_empty(stock_gdfx_top_10_new_df_exist):
        symbol_mapping_create_day = dict(
            zip(stock_gdfx_top_10_new_df_exist['symbol'], stock_gdfx_top_10_new_df_exist['create_day']))

        symbol_mapping_sync_time = dict(
            zip(stock_gdfx_top_10_new_df_exist['symbol'], stock_gdfx_top_10_new_df_exist['sync_time']))

        big_df['create_day'] = big_df['symbol'].map(
            symbol_mapping_create_day).fillna(create_day)
        big_df['sync_time'] = big_df['symbol'].map(
            symbol_mapping_sync_time).fillna(create_day)

    mongodb_util.save_mongo(big_df, db_name_constant.STOCK_GDFX_TOP_10_NEW)


# 同步最新三个季度股东列表
def sync_new_period_ten_gd():
    quarter_list_new = common_util.generate_finance_quarter_dates()
    quarter_list_third = quarter_list_new[0:3]
    for quarter in quarter_list_third:
        try:
            sync_top_ten_free_gd_task(quarter, False)
            sync_top_ten_gd_task(quarter, False)
            logger.info("同步完成:{}", quarter)
        except BaseException as e:
            logger.error("同步异常:{},{}", quarter, str(e))


if __name__ == '__main__':
    quarter_list = common_util.generate_finance_quarter_dates()
    for quarter_test in quarter_list:
        try:
            sync_top_ten_gd_task(quarter_test, False)
            logger.info("同步完成:{}", quarter_test)
        except BaseException as e:
            logger.error("同步异常:{},{}", quarter_test, str(e))
    # sync_top_ten_free_gd_task('20221231')
    # sync_top_ten_gd_task('20251231')



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.api.ths.self_choose.ths_self_choose_api as ths_self_choose_api
import mns_common.constant.db_name_constant as db_name_constant
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.component.cookie.cookie_info_service as cookie_info_service
import mns_common.component.common_service_fun_api as common_service_fun_api
from datetime import datetime
import mns_common.utils.data_frame_util as data_frame_util
import mns_common.constant.self_choose_constant as self_choose_constant
import mns_common.component.trade_date.trade_date_common_service_api as trade_date_common_service_api

mongodb_util = MongodbUtil('27017')


# 固定的选择
# fixed_optional_list = ['USDCNH', 'XAUUSD',
#                        '881279',
#                        '886054', '881153', '881157', '881155',
#                        '885736', '881124', '886078',
#                        '881145', '886073', '881160', '885730',
#                        '886076', '883418', '881169', '885530',
#                        '510300', '512100',
#                        'CN0Y',
#                        '1B0888',
#                        '1A0001',
#                        '399001',
#                        '399006',
#                        '1B0688',
#                        '899050',
#                        'HSI',
#                        'HS2083',
#                        ]

# 固定的选择
# fixed_optional_list = ['899050', '881157']

#
# def add_fixed_optional():
#     ths_cookie = cookie_info_service.get_ths_cookie()
#     for symbol in fixed_optional_list:
#         ths_self_choose_api.add_stock_to_account(symbol, ths_cookie)

# 删除所有自选股票
def delete_all_self_choose_stocks(ths_cookie):
    all_self_choose_stock_list = ths_self_choose_api.get_all_self_choose_stock_list(ths_cookie)
    for stock_one in all_self_choose_stock_list.itertuples():
        symbol = stock_one.code
        ths_self_choose_api.del_stock_from_account(symbol, ths_cookie)


# 添加固定自选股票
def add_self_choose_symbol(ths_cookie):
    # 固定自选
    self_choose_symbol_df = mongodb_util.find_all_data(db_name_constant.SELF_CHOOSE_STOCK)
    if data_frame_util.is_not_empty(self_choose_symbol_df):
        self_choose_symbol_df = self_choose_symbol_df.sort_values(by=['str_now_date'], ascending=False)
        for stock_one in self_choose_symbol_df.itertuples():
            ths_self_choose_api.add_stock_to_account(stock_one.symbol, ths_cookie)


# 添加今日选择股票
def add_today_choose_symbol(ths_cookie):
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    last_trade_day = trade_date_common_service_api.get_last_trade_day(str_day)
    last_trade_day_time = last_trade_day + " 15:00:00"
    query = {'str_now_date': {"$gte": last_trade_day_time}, "valid": True}
    self_choose_symbol_today_df = mongodb_util.find_query_data(db_name_constant.TODAY_SELF_CHOOSE_STOCK, query)
    if data_frame_util.is_not_empty(self_choose_symbol_today_df):
        self_choose_symbol_today_df = self_choose_symbol_today_df.sort_values(by=['str_now_date'], ascending=True)
        for stock_one in self_choose_symbol_today_df.itertuples():
            ths_self_choose_api.add_stock_to_account(stock_one.symbol, ths_cookie)


# 添加同花顺概念
def add_self_choose_concept(ths_cookie):
    query_plate = {'self_type': {
        "$in": [self_choose_constant.SELF_CHOOSE_THS_CONCEPT,
                self_choose_constant.SELF_CHOOSE_THS_INDUSTRY]}}
    self_choose_plate_df = mongodb_util.find_query_data(db_name_constant.SELF_CHOOSE_PLATE, query_plate)
    # 自选同花顺概念
    if data_frame_util.is_not_empty(self_choose_plate_df):
        self_choose_plate_df = self_choose_plate_df.sort_values(by=['str_now_date'], ascending=False)
        for stock_one in self_choose_plate_df.itertuples():
            ths_self_choose_api.add_stock_to_account(str(stock_one.self_code), ths_cookie)


# 添加最近交易股票
def add_trade_stocks(ths_cookie):
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    last_trade_day = trade_date_common_service_api.get_last_trade_day(str_day)
    query = {"$and": [{"str_day": {"$gte": last_trade_day}}, {"str_day": {"$lte": str_day}}]}

    position_stock_df = mongodb_util.find_query_data(db_name_constant.POSITION_STOCK, query)
    if data_frame_util.is_not_empty(position_stock_df):
        stock_list = set(position_stock_df['symbol'])
    else:
        stock_list = set([])
    trade_stocks_df = mongodb_util.find_query_data(db_name_constant.STOCK_BUY_RECORD, query)
    if data_frame_util.is_not_empty(trade_stocks_df):
        stock_list = stock_list.union(set(trade_stocks_df['symbol']))
    if len(stock_list) > 0:
        for symbol in stock_list:
            ths_self_choose_api.add_stock_to_account(symbol, ths_cookie)


# 添加连板到自选
def add_continue_boards_zt_stocks(ths_cookie):
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    if trade_date_common_service_api.is_trade_day(str_day):
        query = {'str_day': str_day}
        stock_zt_pool_df = mongodb_util.find_query_data(db_name_constant.STOCK_ZT_POOL, query)
        if data_frame_util.is_empty(stock_zt_pool_df):
            str_day = trade_date_common_service_api.get_before_trade_date(str_day, 2)
            query = {'str_day': str_day}
            stock_zt_pool_df = mongodb_util.find_query_data(db_name_constant.STOCK_ZT_POOL, query)
    else:
        str_day = trade_date_common_service_api.get_last_trade_day(str_day)
        query = {'str_day': str_day}
        stock_zt_pool_df = mongodb_util.find_query_data(db_name_constant.STOCK_ZT_POOL, query)
    stock_zt_pool_df = stock_zt_pool_df.loc[stock_zt_pool_df['connected_boards_numbers'] >= 3]
    stock_zt_pool_df = common_service_fun_api.exclude_st_symbol(stock_zt_pool_df)
    stock_zt_pool_df = stock_zt_pool_df.sort_values(by=['connected_boards_numbers'], ascending=False)
    for stock_one in stock_zt_pool_df.itertuples():
        ths_self_choose_api.add_stock_to_account(stock_one.symbol, ths_cookie)


# 添加主线龙头
def add_main_line_leader(ths_cookie):
    main_line_leader_df = mongodb_util.find_query_data('main_line_leader', {})
    if data_frame_util.is_not_empty(main_line_leader_df):
        main_line_leader_df = count_main_line_number(main_line_leader_df)

        main_line_leader_df = main_line_leader_df.sort_values(
            by=['main_line_number', 'main_line_leader_grade'],
            ascending=[False, False,]
        )
        for stock_one in main_line_leader_df.itertuples():
            ths_self_choose_api.add_stock_to_account(stock_one.symbol, ths_cookie)


# 统计主线的数量
def count_main_line_number(main_line_detail_df):
    # 统计主线的数量
    main_line_detail_df['main_line_number'] = main_line_detail_df.groupby('main_line')['main_line'].transform(
        'count')
    # 相同主线数量 数量加1
    main_line_detail_df['main_line_number'] = (
                                                      main_line_detail_df.groupby('main_line_number')['main_line']
                                                      .transform('rank', method='dense') - 1
                                              ) * 0.1 + main_line_detail_df['main_line_number']

    return main_line_detail_df


# 自选股操作 删除当天自选股 增加新的连板股票  添加固定选择自选
def self_choose_stock_handle():
    ths_cookie = cookie_info_service.get_ths_cookie()

    delete_all_self_choose_stocks(ths_cookie)
    # 固定自选板块
    # add_fixed_optional()
    # 添加同花顺概念
    add_self_choose_concept(ths_cookie)
    # 添加主线龙头
    add_main_line_leader(ths_cookie)
    # 连板股票
    add_continue_boards_zt_stocks(ths_cookie)

    # 自己买入的股票
    add_trade_stocks(ths_cookie)
    # 添加自选股票
    add_self_choose_symbol(ths_cookie)


if __name__ == '__main__':
    # add_continue_boards_zt_stocks()
    self_choose_stock_handle()
